import ij.*;
import imageware.*;

/**
* Class MacroWatershed_.
* 
* Easy example of calling watershed methods.
*
* @author	Daniel Sage
*			Biomedical Imaging Group
*			Swiss Federal Institute of Technology Lausanne
*			EPFL, CH-1015 Lausanne, Switzerland
*/

public class MacroWatershed_ {

	public MacroWatershed_() {
		
		// Get the input image
		ImagePlus imp = WindowManager.getCurrentImage();
		if (imp == null) {
			IJ.error("No open image.");
			return;
		}
		
		if (imp.getType() != ImagePlus.GRAY8 && imp.getType() != ImagePlus.GRAY32) {
			IJ.error("Require a 8-bit or 32-bit image.");
			return;
		}
		
		ImageWare image = Builder.wrap(imp);
		
		// Invert the image to segment black objects 
		image.invert();
		
		// Show the image to avoid oversegmentation
		double sigma = 2.0;
		image.smoothGaussian(sigma);
		image.show("Smooth image");

		// Start the watershed segmentation
		boolean displayProgressionMessage = true;
		Watershed watershed = new Watershed(displayProgressionMessage);
		
		boolean connectivity4 = true;
		int maxLevel = 200;
		watershed.doWatershed(image, connectivity4, maxLevel);
		
		// Available outputs
		ImagePlus dams = watershed.getDams();
		dams.show();

		ImagePlus reddams = watershed.getRedDams(imp);
		reddams.show();
		
		ImagePlus basins = watershed.getBasins();
		basins.show();

		ImagePlus composite = watershed.getComposite(imp);
		composite.show();
		
		// Make measurements
		WatershedMeasurements.measure(composite);
		
	}
}

